.. _v1_1:

Version 1.1
===========

Summary
-------

.. qrefflask:: flexmeasures.app:create(env="documentation")
    :blueprints: flexmeasures_api, flexmeasures_api_play, flexmeasures_api_v1_1
    :order: path
    :include-empty-docstring:

API Details
-----------

.. autoflask:: flexmeasures.app:create(env="documentation")
    :blueprints: flexmeasures_api, flexmeasures_api_play, flexmeasures_api_v1_1
    :order: path
    :include-empty-docstring:
